'use strict';

var _modulePathHash = require('../utils/modulePathHash');

var _modulePathHash2 = _interopRequireDefault(_modulePathHash);

var _chunkNameHash = require('../utils/chunkNameHash');

var _chunkNameHash2 = _interopRequireDefault(_chunkNameHash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Useful references:
// https://github.com/webpack/docs/wiki/How-to-write-a-plugin
// https://webpack.github.io/docs/api-in-modules.html

function CodeSplitPlugin(options) {
  this.options = options || {};
}

CodeSplitPlugin.prototype.apply = function apply(compiler) {
  var _this = this;

  var options = this.options;
  compiler.plugin('compilation', function (compilation) {
    compilation.plugin('before-module-ids', function (modules) {
      if (options.disabled) {
        return;
      }

      modules.forEach(function (module) {
        if (module.id === null && module.libIdent) {
          var createHashedModuleId = module.resource.indexOf('node_modules') === -1 && module.chunks.length > 0;
          if (createHashedModuleId) {
            module.id = (0, _modulePathHash2.default)(module.resource); // eslint-disable-line no-param-reassign
          } else {
              // Otherwise we will use the standard number based identifiers.
            }
        }
      }, _this);
    });
    compilation.plugin('before-chunk-ids', function (chunks) {
      if (options.disabled) {
        return;
      }

      chunks.forEach(function (chunk) {
        if (chunk.id === null && chunk.name) {
          chunk.id = (0, _chunkNameHash2.default)(chunk.name); // eslint-disable-line no-param-reassign
        }
      });
    });
  });
};

module.exports = CodeSplitPlugin;